==> tiltfive_sdk_1.3.3.tar.xz: tiltfive_sdk_1.3.3/Native/docs/html/annotated_dup.js <==
var annotated_dup =
[
    [ "std", null, [
      [ "is_error_code_enum< tiltfive::Error >", "a03596.html", null ]
    ] ],
    [ "tiltfive", null, [
      [ "details", null, [
        [ "ErrorCategory", "a03592.html", null ]
      ] ],
      [ "BadResultAccess", "a03600.html", null ],
      [ "Client", "a03636.html", "a03636" ],
      [ "Glasses", "a03640.html", "a03640" ],
      [ "GlassesConnectionHelper", "a03644.html", "a03644" ],
      [ "ParamChangeHelper", "a03656.html", "a03656" ],
      [ "ParamChangeListener", "a03652.html", "a03652" ],
      [ "Result", "a03604.html", null ],
      [ "Result< void >", "a03616.html", null ],
      [ "supports_ostream", "a03624.html", null ],
      [ "supports_ostream< T, decltype(std::declval< std::ostream & >()<< std::declval< T >())>", "a03628.html", null ],
      [ "Wand", "a03660.html", "a03660" ],
      [ "WandStreamHelper", "a03648.html", "a03648" ]
    ] ],
    [ "T5_CameraStreamConfig", "a03688.html", "a03688" ],
    [ "T5_CamImage", "a03700.html", "a03700" ],
    [ "T5_ClientInfo", "a03680.html", "a03680" ],
    [ "T5_FrameInfo", "a03692.html", "a03692" ],
    [ "T5_GameboardSize", "a03676.html", "a03676" ],
    [ "T5_GlassesPose", "a03684.html", "a03684" ],
    [ "T5_Quat", "a03672.html", null ],
    [ "T5_Vec2", "a03664.html", null ],
    [ "T5_Vec3", "a03668.html", null ],
    [ "T5_WandReport", "a03708.html", "a03708" ],
    [ "T5_WandStreamConfig", "a03704.html", "a03704" ],
    [ "T5_WandStreamEvent", "a03716.html", "a03716" ]
];

==> tiltfive_sdk_1.4.0.tar.xz: tiltfive_sdk_1.4.0/Native/docs/html/annotated_dup.js <==
var annotated_dup =
[
    [ "std", null, [
      [ "is_error_code_enum< tiltfive::Error >", "a03596.html", null ]
    ] ],
    [ "tiltfive", null, [
      [ "details", null, [
        [ "ErrorCategory", "a03592.html", null ]
      ] ],
      [ "BadResultAccess", "a03600.html", null ],
      [ "Client", "a03636.html", "a03636" ],
      [ "Glasses", "a03640.html", "a03640" ],
      [ "GlassesConnectionHelper", "a03644.html", "a03644" ],
      [ "ParamChangeHelper", "a03656.html", "a03656" ],
      [ "ParamChangeListener", "a03652.html", "a03652" ],
      [ "Result", "a03604.html", null ],
      [ "Result< void >", "a03616.html", null ],
      [ "supports_ostream", "a03624.html", null ],
      [ "supports_ostream< T, decltype(std::declval< std::ostream & >()<< std::declval< T >())>", "a03628.html", null ],
      [ "Wand", "a03660.html", "a03660" ],
      [ "WandStreamHelper", "a03648.html", "a03648" ]
    ] ],
    [ "T5_CameraStreamConfig", "a03696.html", "a03696" ],
    [ "T5_CamImage", "a03708.html", "a03708" ],
    [ "T5_ClientInfo", "a03688.html", "a03688" ],
    [ "T5_FrameInfo", "a03700.html", "a03700" ],
    [ "T5_GameboardSize", "a03684.html", "a03684" ],
    [ "T5_GlassesPose", "a03692.html", "a03692" ],
    [ "T5_GraphicsContextGL", "a03676.html", "a03676" ],
    [ "T5_GraphicsContextVulkan", "a03680.html", "a03680" ],
    [ "T5_ProjectionInfo", "a03728.html", "a03728" ],
    [ "T5_Quat", "a03672.html", null ],
    [ "T5_Vec2", "a03664.html", null ],
    [ "T5_Vec3", "a03668.html", null ],
    [ "T5_WandReport", "a03716.html", "a03716" ],
    [ "T5_WandStreamConfig", "a03712.html", "a03712" ],
    [ "T5_WandStreamEvent", "a03724.html", "a03724" ]
];
